@@ -20,6 +20,8 @@ from eva.configuration.dictionary import EVA_DEFAULT_DIR, \
     EVA_CONFIG_FILE
 from eva.configuration.config_utils import read_value_config, \
     update_value_config
+from eva.configuration.bootstrap_environment import \
+    bootstrap_environment
 
 
 class ConfigurationManager(object):
@@ -30,6 +32,8 @@ class ConfigurationManager(object):
         if cls._instance is None:
             cls._instance = super(ConfigurationManager, cls).__new__(cls)
 
+            bootstrap_environment()  # Setup eva in home directory
+
             ymlpath = EVA_DEFAULT_DIR + EVA_CONFIG_FILE
             with open(ymlpath, 'r') as ymlfile:
                 cls._cfg = yaml.load(ymlfile, Loader=yaml.FullLoader)
